@@ -320,7 +320,8 @@ class Move(Workflow, ModelSQL, ModelView):
             'from_location', 'to_location', 'company', 'currency'])
         cls._deny_modify_done_cancel = (cls._deny_modify_assigned
             | set(['planned_date', 'effective_date', 'state']))
-        cls._allow_modify_closed_period = {'cost_price', 'unit_price'}
+        cls._allow_modify_closed_period = {
+            'cost_price', 'unit_price', 'unit_price_updated'}
 
         t = cls.__table__()
         cls._sql_constraints += [
@@ -473,7 +474,7 @@ class Move(Workflow, ModelSQL, ModelView):
             return True
         if from_type in {'storage', 'drop'} and to_type == 'supplier':
             return True
-        if from_type == 'customer' and to_type == {'storage', 'drop'}:
+        if from_type == 'customer' and to_type in {'storage', 'drop'}:
             return True
         return False
 
